@@ -59,15 +59,24 @@ try:
         :return: the matplotlib object
         :rtype: list of Text instance
 
-        Example:
-
-        .. runblock:: pycon
+        Example::
 
             >>> from spatialmath.base import plotvol2, plot_text
             >>> plotvol2(5)
             >>> plot_text((1,3), 'foo')
-            >>> plot_text((2,2), 'bar', 'b')
+            >>> plot_text((2,2), 'bar', color='b')
             >>> plot_text((2,2), 'baz', fontsize=14, horizontalalignment='centre')
+
+        .. plot::
+
+            from spatialmath.base import plotvol2, plot_text
+            ax = plotvol2(5)
+            plot_text((0,0), 'foo')
+            plot_text((1,1), 'bar', color='b')
+            plot_text((2,2), 'baz', fontsize=14, horizontalalignment='center')
+            ax.grid()
+
+        :seealso: :func:`plot_point`
         """
 
         defaults = {"horizontalalignment": "left", "verticalalignment": "center"}
@@ -128,22 +137,63 @@ try:
             will label each point with its index (argument 0) and consecutive
             elements of ``a`` and ``b`` which are arguments 1 and 2 respectively.
 
-        Examples:
+        Example::
 
-        - ``plot_point((1,2))`` plot default marker at coordinate (1,2)
-        - ``plot_point((1,2), 'r*')`` plot red star at coordinate (1,2)
-        - ``plot_point((1,2), 'r*', 'foo')`` plot red star at coordinate (1,2) and
+            >>> from spatialmath.base import plotvol2, plot_text
+            >>> plotvol2(5)
+            >>> plot_point((0, 0))        # plot default marker at coordinate (1,2)
+            >>> plot_point((1,1), 'r*')  # plot red star at coordinate (1,2)
+            >>> plot_point((2,2), 'r*', 'foo')  # plot red star at coordinate (1,2) and
         label it as 'foo'
-        - ``plot_point(p, 'r*')`` plot red star at points defined by columns of
-        ``p``.
-        - ``plot_point(p, 'r*', 'foo')`` plot red star at points defined by columns
-        of ``p`` and label them all as 'foo'
-        - ``plot_point(p, 'r*', '{0}')`` plot red star at points defined by columns
-        of ``p`` and label them sequentially from 0
-        - ``plot_point(p, 'r*', ('{1:.1f}', z))`` plot red star at points defined by
-        columns of ``p`` and label them all with successive elements of ``z``.
+
+        .. plot::
+
+            from spatialmath.base import plotvol2, plot_text
+            ax = plotvol2(5)
+            plot_point((0, 0))
+            plot_point((1,1), 'r*')
+            plot_point((2,2), 'r*', 'foo')
+            ax.grid()
+
+        Plot red star at points defined by columns of ``p`` and label them sequentially
+        from 0::
+
+            >>> p = np.random.uniform(size=(2,10), low=-5, high=5)
+            >>> plotvol2(5)
+            >>> plot_point(p, 'r*', '{0}')
+
+        .. plot::
+
+            from spatialmath.base import plotvol2, plot_point
+            import numpy as np
+            p = np.random.uniform(size=(2,10), low=-5, high=5)
+            ax = plotvol2(5)
+            plot_point(p, 'r*', '{0}')
+            ax.grid()
+
+        Plot red star at points defined by columns of ``p`` and label them all with
+        successive elements of ``z``
+
+            >>> p = np.random.uniform(size=(2,10), low=-5, high=5)
+            >>> value = np.random.uniform(size=(1,10))
+            >>> plotvol2(5)
+            >>> plot_point(p, 'r*', ('{1:.2f}', value))
+
+        .. plot::
+
+            from spatialmath.base import plotvol2, plot_point
+            import numpy as np
+            p = np.random.uniform(size=(2,10), low=-5, high=5)
+            value = np.random.uniform(size=(10,))
+            ax = plotvol2(5)
+            plot_point(p, 'r*', ('{1:.2f}', value))
+            ax.grid()
+
+        :seealso: :func:`plot_text`
         """
 
+        defaults = {"horizontalalignment": "left", "verticalalignment": "center"}
+
         if isinstance(pos, np.ndarray):
             if pos.ndim == 1:
                 x = pos[0]
@@ -195,12 +245,16 @@ try:
                 for i, (x, y) in enumerate(xy):
                     handles.append(ax.text(x, y, " " + text.format(i), **textopts))
             elif isinstance(text, (tuple, list)):
+                (
+                    fmt,
+                    *values,
+                ) = text  # unpack (fmt, values...)  values is iterable, one per point
                 for i, (x, y) in enumerate(xy):
                     handles.append(
                         ax.text(
                             x,
                             y,
-                            " " + text[0].format(i, *[d[i] for d in text[1:]]),
+                            " " + fmt.format(i, *[d[i] for d in values]),
                             **textopts,
                         )
                     )
@@ -233,14 +287,22 @@ try:
 
         If ``lines`` is a 3xN array then ``N`` lines are drawn, one per column.
 
-        Example:
-
-        .. runblock:: pycon
+        Example::
 
             >>> from spatialmath.base import plotvol2, plot_homline
             >>> plotvol2(5)
             >>> plot_homline((1, -2, 3))
             >>> plot_homline((1, -2, 3), 'k--') # dashed black line
+
+        .. plot::
+
+            from spatialmath.base import plotvol2, plot_homline
+            ax = plotvol2(5)
+            plot_homline((1, -2, 3))
+            plot_homline((1, -2, 3), 'k--') # dashed black line
+            ax.grid()
+
+        :seealso: :func:`plot_arrow`
         """
         ax = axes_logic(ax, 2)
         # get plot limits from current graph
@@ -286,14 +348,14 @@ try:
         """
         Plot a 2D box using matplotlib
 
-        :param bl: bottom-left corner, defaults to None
-        :type bl: array_like(2), optional
-        :param tl: top-left corner, defaults to None
-        :type tl: array_like(2), optional
-        :param br: bottom-right corner, defaults to None
-        :type br: array_like(2), optional
-        :param tr: top-right corner, defaults to None
-        :type tr: array_like(2), optional
+        :param lb: left-bottom corner, defaults to None
+        :type lb: array_like(2), optional
+        :param lt: left-top corner, defaults to None
+        :type lt: array_like(2), optional
+        :param rb: right-bottom corner, defaults to None
+        :type rb: array_like(2), optional
+        :param rt: right-top corner, defaults to None
+        :type rt: array_like(2), optional
         :param wh: width and height, if both are the same provide scalar, defaults to None
         :type wh: scalar, array_like(2), optional
         :param centre: centre of box, defaults to None
@@ -315,30 +377,34 @@ try:
         :param thickness: line thickness, defaults to None
         :type thickness: float, optional
         :return: the matplotlib object
-        :rtype: list of Line2D or Patch.Rectangle instance
+        :rtype: Patch.Rectangle instance
 
         The box can be specified in many ways:
 
-        - bounding box which is a 2x2 matrix [xmin, xmax, ymin, ymax]
         - bounding box [xmin, xmax, ymin, ymax]
         - alternative box [xmin, ymin, xmax, ymax]
         - centre and width+height
-        - bottom-left and top-right corners
-        - bottom-left corner and width+height
-        - top-right corner and width+height
-        - top-left corner and width+height
+        - left-bottom and right-top corners
+        - left-bottom corner and width+height
+        - right-top corner and width+height
+        - left-top corner and width+height
 
         For plots where the y-axis is inverted (eg. for images) then top is the
         smaller vertical coordinate.
 
-        Example:
+        Example::
 
-        .. runblock:: pycon
-
-            >>> from spatialmath.base import plotvol2, plot_box
             >>> plotvol2(5)
-            >>> plot_box('r', centre=(2,3), wh=1) # w=h=1
-            >>> plot_box(tl=(1,1), br=(0,2), filled=True, color='b')
+            >>> plot_box("b--", centre=(2, 3), wh=1)  # w=h=1
+            >>> plot_box(lt=(0, 0), rb=(3, -2), filled=True, color="r")
+
+        .. plot::
+
+            from spatialmath.base import plotvol2, plot_box
+            ax = plotvol2(5)
+            plot_box("b--", centre=(2, 3), wh=1)  # w=h=1
+            plot_box(lt=(0, 0), rb=(3, -2), filled=True, hatch="/", edgecolor="k", color="r")
+            ax.grid()
         """
 
         if wh is not None:
@@ -407,50 +473,133 @@ try:
 
         # we only need lb, wh
         ax = axes_logic(ax, 2)
+
         if filled:
-            r = plt.Rectangle(lb, w, h, clip_on=True, **kwargs)
+            r = plt.Rectangle(lb, w, h, fill=True, clip_on=True, **kwargs)
         else:
+            ec = None
+            ls = ""
+            if len(fmt) > 0:
+                colors = "rgbcmywk"
+                for f in fmt[0]:
+                    if f in colors:
+                        ec = f
+                    else:
+                        ls += f
+            if ls == "":
+                ls = None
+
             if "color" in kwargs:
-                kwargs["edgecolor"] = kwargs["color"]
+                ec = kwargs["color"]
                 del kwargs["color"]
-            r = plt.Rectangle(lb, w, h, clip_on=True, facecolor="None", **kwargs)
+            r = plt.Rectangle(
+                lb, w, h, clip_on=True, linestyle=ls, edgecolor=ec, fill=False, **kwargs
+            )
         ax.add_patch(r)
 
         return r
 
     def plot_arrow(
-        start: ArrayLike2, end: ArrayLike2, ax: Optional[plt.Axes] = None, **kwargs
+        start: ArrayLike2,
+        end: ArrayLike2,
+        label: Optional[str] = None,
+        label_pos: str = "above:0.5",
+        ax: Optional[plt.Axes] = None,
+        **kwargs,
     ) -> List[plt.Artist]:
-        """
+        r"""
         Plot 2D arrow
 
         :param start: start point, arrow tail
         :type start: array_like(2)
         :param end: end point, arrow head
         :type end: array_like(2)
+        :param label: arrow label text, optional
+        :type label: str
+        :param label_pos: position of arrow label "above|below:fraction", optional
+        :type label_pos: str
         :param ax: axes to draw into, defaults to None
         :type ax: Axes, optional
         :param kwargs: argumetns to pass to :class:`matplotlib.patches.Arrow`
 
-        Example:
+        Draws an arrow from ``start`` to ``end``.
 
-        .. runblock:: pycon
+        A ``label``, if given, is drawn above or below the arrow.  The position of the
+        label is controlled by ``label_pos`` which is of the form
+        ``"position:fraction"`` where ``position`` is either ``"above"`` or ``"below"``
+        the arrow, and ``fraction`` is a float between 0 (tail) and 1 (head) indicating
+        the distance along the arrow where the label will be placed.  The text is
+        suitably justified to not overlap the arrow.
+
+        Example::
 
             >>> from spatialmath.base import plotvol2, plot_arrow
             >>> plotvol2(5)
-            >>> plot_arrow((-2, 2), (3, 4), color='r', width=0.1)  # red arrow
+            >>> plot_arrow((-2, 2), (2, 4), color='r', width=0.1)  # red arrow
+            >>> plot_arrow((4, 1), (2, 4), color='b', width=0.1)  # blue arrow
+
+        .. plot::
+
+            from spatialmath.base import plotvol2, plot_arrow
+            ax = plotvol2(5)
+            plot_arrow((-2, 2), (3, 4), color='r', width=0.1)  # red arrow
+            plot_arrow((4, 1), (3, 4), color='b', width=0.1)  # blue arrow
+            ax.grid()
+
+        Example::
+
+            >>> from spatialmath.base import plotvol2, plot_arrow
+            >>> plotvol2(5)
+            >>> plot_arrow((-2, -2), (2, 4), label=r"$\mathit{p}_3$", color='r', width=0.1)
+
+        .. plot::
+
+            from spatialmath.base import plotvol2, plot_arrow
+            ax = plotvol2(5)
+            ax.grid()
+            plot_arrow(
+                (-2, -2), (2, 4), label="$\mathit{p}_3$", color="r", width=0.1
+            )
+            plt.show(block=True)
+
+        :seealso: :func:`plot_homline`
         """
         ax = axes_logic(ax, 2)
 
+        dx = end[0] - start[0]
+        dy = end[1] - start[1]
         ax.arrow(
             start[0],
             start[1],
-            end[0] - start[0],
-            end[1] - start[1],
+            dx,
+            dy,
             length_includes_head=True,
             **kwargs,
         )
 
+        if label is not None:
+            # add a label
+            label_pos = label_pos.split(":")
+            if label_pos[0] == "below":
+                above = False
+            try:
+                fraction = float(label_pos[1])
+            except:
+                fraction = 0.5
+
+            theta = np.arctan2(dy, dx)
+            quadrant = theta // (np.pi / 2)
+            pos = [start[0] + fraction * dx, start[1] + fraction * dy]
+            if quadrant in (0, 2):
+                # quadrants 1 and 3, line is sloping up to right or down to left
+                opt = {"verticalalignment": "bottom", "horizontalalignment": "right"}
+                label = label + " "
+            else:
+                # quadrants 2 and 4, line is sloping up to left or down to right
+                opt = {"verticalalignment": "top", "horizontalalignment": "left"}
+                label = " " + label
+            ax.text(*pos, label, **opt)
+
     def plot_polygon(
         vertices: NDArray, *fmt, close: Optional[bool] = False, **kwargs
     ) -> List[plt.Artist]:
@@ -465,14 +614,20 @@ try:
         :return: Matplotlib artist
         :rtype: line or patch
 
-        Example:
-
-        .. runblock:: pycon
+        Example::
 
             >>> from spatialmath.base import plotvol2, plot_polygon
             >>> plotvol2(5)
             >>> vertices = np.array([[-1, 2, -1], [1, 0, -1]])
             >>> plot_polygon(vertices, filled=True, facecolor='g')  # green filled triangle
+
+        .. plot::
+
+            from spatialmath.base import plotvol2, plot_polygon
+            ax = plotvol2(5)
+            vertices = np.array([[-1, 2, -1], [1, 0, -1]])
+            plot_polygon(vertices, filled=True, facecolor='g')  # green filled triangle
+            ax.grid()
         """
 
         if close:
@@ -488,7 +643,6 @@ try:
         fmt: Optional[Callable] = None,
         **kwargs,
     ) -> List[plt.Artist]:
-
         ax = axes_logic(ax, 2)
         if pose is not None:
             vertices = pose * vertices
@@ -520,6 +674,8 @@ try:
         :type radius: float, optional
         :param resolution: number of points on circumferece, defaults to 50
         :type resolution: int, optional
+        :param closed: perimeter is closed, last point == first point, defaults to False
+        :type closed: bool
         :return: points on circumference
         :rtype: ndarray(2,N) or ndarray(3,N)
 
@@ -568,15 +724,22 @@ try:
         taken as the centre of a circle.  All circles have the same radius, color
         etc.
 
-        Example:
-
-        .. runblock:: pycon
+        Example::
 
             >>> from spatialmath.base import plotvol2, plot_circle
             >>> plotvol2(5)
-            >>> plot_circle(1, 'r')  # red circle
-            >>> plot_circle(2, 'b--')  # blue dashed circle
-            >>> plot_circle(0.5, filled=True, facecolor='y')  # yellow filled circle
+            >>> plot_circle(1, (0,0), 'r')  # red circle
+            >>> plot_circle(2, (1, 2), 'b--')  # blue dashed circle
+            >>> plot_circle(0.5, (3,4), filled=True, facecolor='y')  # yellow filled circle
+
+        .. plot::
+
+            from spatialmath.base import plotvol2, plot_circle
+            ax = plotvol2(5)
+            plot_circle(1, (0,0), 'r')  # red circle
+            plot_circle(2, (1, 2), 'b--')  # blue dashed circle
+            plot_circle(0.5, (3,4), filled=True, facecolor='y')  # yellow filled circle
+            ax.grid()
         """
         centres = smb.getmatrix(centre, (2, None))
 
@@ -616,6 +779,8 @@ try:
         :type resolution: int, optional
         :param inverted: if :math:`\mat{E}^{-1}` is provided, defaults to False
         :type inverted: bool, optional
+        :param closed: perimeter is closed, last point == first point, defaults to False
+        :type closed: bool
         :raises ValueError: [description]
         :return: points on circumference
         :rtype: ndarray(2,N)
@@ -654,8 +819,8 @@ try:
 
     def plot_ellipse(
         E: R2x2,
+        centre: ArrayLike2,
         *fmt: Optional[str],
-        centre: Optional[ArrayLike2] = (0, 0),
         scale: Optional[float] = 1,
         confidence: Optional[float] = None,
         resolution: Optional[int] = 40,
@@ -694,14 +859,20 @@ try:
 
         Example:
 
-        .. runblock:: pycon
-
-            >>> from spatialmath.base import plotvol2, plot_circle
+            >>> from spatialmath.base import plotvol2, plot_ellipse
             >>> plotvol2(5)
-            >>> plot_ellipse(np.diag((1,2)), 'r')  # red ellipse
-            >>> plot_ellipse(np.diag((1,2)), 'b--')  # blue dashed ellipse
-            >>> plot_ellipse(np.diag((1,2)), filled=True, facecolor='y')  # yellow filled ellipse
+            >>> plot_ellipse(np.array([[1, 1], [1, 2]]), [0,0], 'r')  # red ellipse
+            >>> plot_ellipse(np.array([[1, 1], [1, 2]]), [1, 2], 'b--')  # blue dashed ellipse
+            >>> plot_ellipse(np.array([[1, 1], [1, 2]]), [-2, -1], filled=True, facecolor='y')  # yellow filled ellipse
 
+        .. plot::
+
+            from spatialmath.base import plotvol2, plot_ellipse
+            ax = plotvol2(5)
+            plot_ellipse(np.array([[1, 1], [1, 2]]), [0,0], 'r')  # red ellipse
+            plot_ellipse(np.array([[1, 1], [1, 2]]), [1, 2], 'b--')  # blue dashed ellipse
+            plot_ellipse(np.array([[1, 1], [1, 2]]), [-2, -1], filled=True, facecolor='y')  # yellow filled ellipse
+            ax.grid()
         """
         # allow for centre[2] to plot ellipse in a plane in a 3D plot
 
@@ -780,14 +951,28 @@ try:
         taken as the centre of a sphere.  All spheres have the same radius, color
         etc.
 
-        Example:
-
-        .. runblock:: pycon
+        Example::
 
             >>> from spatialmath.base import plot_sphere
-            >>> plot_sphere(radius=1, color='r')   # red sphere wireframe
+            >>> plot_sphere(radius=1, color="r", resolution=10)   # red sphere wireframe
             >>> plot_sphere(radius=1, centre=(1,1,1), filled=True, facecolor='b')
 
+
+        .. plot::
+
+            from spatialmath.base import plot_sphere, plotvol3
+
+            plotvol3(2)
+            plot_sphere(radius=1, color='r', resolution=5)   # red sphere wireframe
+
+        .. plot::
+
+            from spatialmath.base import plot_sphere, plotvol3
+
+            plotvol3(5)
+            plot_sphere(radius=1, centre=(1,1,1), filled=True, facecolor='b')
+
+
         :seealso: :func:`~matplotlib.pyplot.plot_surface`, :func:`~matplotlib.pyplot.plot_wireframe`
         """
         ax = axes_logic(ax, 3)
@@ -855,9 +1040,10 @@ try:
             E = np.linalg.inv(E)
 
         x, y, z = sphere()  # unit sphere
+        centre = smb.getvector(centre, 3, out="col")
         e = (
-            s * sqrtm(E) @ np.array([x.flatten(), y.flatten(), z.flatten()])
-            + np.c_[centre].T
+            scale * sqrtm(E) @ np.array([x.flatten(), y.flatten(), z.flatten()])
+            + centre
         )
         return (
             e[0, :].reshape(x.shape),
@@ -866,7 +1052,7 @@ try:
         )
 
     def plot_ellipsoid(
-        E: R2x2,
+        E: R3x3,
         centre: Optional[ArrayLike3] = (0, 0, 0),
         scale: Optional[float] = 1,
         confidence: Optional[float] = None,
@@ -897,16 +1083,20 @@ try:
         :param stride: [description], defaults to 1
         :type stride: int, optional
 
-        ``plot_ellipse(E)`` draws the ellipsoid defined by :math:`x^T \mat{E} x = 0`
+        ``plot_ellipsoid(E)`` draws the ellipsoid defined by :math:`x^T \mat{E} x = 0`
         on the current plot.
 
         Example::
 
-            H = plot_ellipse(diag([1 2]), [3 4]', 'r'); % draw red ellipse
-            plot_ellipse(diag([1 2]), [5 6]', 'alter', H); % move the ellipse
-            plot_ellipse(diag([1 2]), [5 6]', 'alter', H, 'LineColor', 'k'); % change color
+            >>> plot_ellipsoid(np.diag([1, 2, 3]), [1, 1, 0], color="r", resolution=10); # draw red ellipsoid
 
-            plot_ellipse(COVAR, 'confidence', 0.95); % draw 95% confidence ellipse
+        .. plot::
+
+            from spatialmath.base import plot_ellipsoid, plotvol3
+            import numpy as np
+
+            plotvol3(4)
+            plot_ellipsoid(np.diag([1, 2, 3]), [1, 1, 0], color="r", resolution=5); # draw red ellipsoid
 
         .. note::
 
@@ -980,7 +1170,7 @@ try:
         :type height: float or array_like(2)
         :param resolution: number of points on circumference, defaults to 50
         :param centre: position of centre
-        :param pose: pose of sphere, defaults to None
+        :param pose: pose of cylinder, defaults to None
         :type pose: SE3, optional
         :param ax: axes to draw into, defaults to None
         :type ax: Axes3D, optional
@@ -997,6 +1187,18 @@ try:
         The cylinder can be positioned by setting ``centre``, or positioned
         and orientated by setting ``pose``.
 
+        Example::
+
+            >>> plot_cylinder(radius=1, height=(1,3))
+
+        .. plot::
+
+            from spatialmath.base import plot_cylinder, plotvol3
+
+            plotvol3(5)
+            plot_cylinder(radius=1, height=(1,3))
+
+
         :seealso: :func:`~matplotlib.pyplot.plot_surface`, :func:`~matplotlib.pyplot.plot_wireframe`
         """
         if smb.isscalar(height):
@@ -1066,6 +1268,17 @@ try:
         The cylinder can be positioned by setting ``centre``, or positioned
         and orientated by setting ``pose``.
 
+        Example::
+
+            >>> plot_cone(radius=1, height=2)
+
+        .. plot::
+
+            from spatialmath.base import plot_cone, plotvol3
+
+            plotvol3(5)
+            plot_cone(radius=1, height=2)
+
         :seealso: :func:`~matplotlib.pyplot.plot_surface`, :func:`~matplotlib.pyplot.plot_wireframe`
         """
         ax = axes_logic(ax, 3)
@@ -1127,6 +1340,17 @@ try:
         :return: matplotlib collection
         :rtype: Line3DCollection or Poly3DCollection
 
+        Example::
+
+            >>> plot_cone(radius=1, height=2)
+
+        .. plot::
+
+            from spatialmath.base import plot_cuboid, plotvol3
+
+            plotvol3(5)
+            plot_cuboid(sides=(3,2,1), centre=(0,1,2))
+
         :seealso: :func:`~matplotlib.pyplot.plot_surface`, :func:`~matplotlib.pyplot.plot_wireframe`
         """
 
@@ -1194,7 +1418,6 @@ try:
         color: Optional[Color] = None,
         **kwargs,
     ):
-
         # TODO:
         # handle pose in here
         # do the guts of plot_surface/wireframe but skip the auto scaling
@@ -1231,12 +1454,17 @@ try:
         :return: dimensionality of axes, either 2 or 3
         :rtype: int
         """
-        classname = ax.__class__.__name__
 
-        if classname in ("Axes3DSubplot", "Animate"):
-            return 3
-        elif classname in ("AxesSubplot", "Animate2"):
-            return 2
+        if hasattr(ax, "name"):
+            # handle the case of some kind of matplotlib Axes
+            return 3 if ax.name == "3d" else 2
+        else:
+            # handle the case of Animate objects pretending to be Axes
+            classname = ax.__class__.__name__
+            if classname == "Animate":
+                return 3
+            elif classname == "Animate2":
+                return 2
 
     def axes_get_limits(ax: plt.Axes) -> NDArray:
         return np.r_[ax.get_xlim(), ax.get_ylim()]
@@ -1295,6 +1523,8 @@ try:
             # need to be careful to not use gcf() or gca() since they
             # auto create fig/axes if none exist
             nfigs = len(plt.get_fignums())
+            # print(f"there are {nfigs} figures")
+
             if nfigs > 0:
                 # there are figures
                 fig = plt.gcf()  # get current figure
@@ -1302,11 +1532,13 @@ try:
                 # print(f"existing fig with {naxes} axes")
                 if naxes > 0:
                     ax = plt.gca()  # get current axes
+                    # print(f"ax has {_axes_dimensions(ax)} dimensions")
                     if _axes_dimensions(ax) == dimensions:
                         return ax
             # otherwise it doesnt exist or dimension mismatch, create new axes
-
+            # print("create new axes")
         else:
+            # print("no figs present, ax given")
             # axis was given
 
             if _axes_dimensions(ax) == dimensions:
